lidarwind.wind\_prop\_retrieval\_6\_beam.SixBeamMethod
======================================================

.. currentmodule:: lidarwind.wind_prop_retrieval_6_beam

.. autoclass:: SixBeamMethod

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~SixBeamMethod.__init__
      ~SixBeamMethod.calc_variances
      ~SixBeamMethod.get_m_matrix
      ~SixBeamMethod.get_m_matrix_inv
      ~SixBeamMethod.get_s_matrix
      ~SixBeamMethod.get_sigma
      ~SixBeamMethod.get_variance
      ~SixBeamMethod.get_variance_ds
   
   

   
   
   